@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Cookies API for Server & Client - ~/lib/Cookie.pm
-## Version v0.1.1
+## Version v0.1.2
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2019/10/08
-## Modified 2021/11/17
+## Modified 2021/11/18
 ## You can use, copy, modify and  redistribute  this  package  and  associated
 ## files under the same terms as Perl itself.
 ##----------------------------------------------------------------------------
@@ -27,7 +27,7 @@ BEGIN
         '=='     => \&same_as,
         fallback => 1,
     );
-    our $VERSION = 'v0.1.1';
+    our $VERSION = 'v0.1.2';
     our $SUBS;
     our $COOKIE_DEBUG = 0;
 };
@@ -814,11 +814,11 @@ Cookie - Cookie Object
 
 =head1 VERSION
 
-    v0.1.1
+    v0.1.2
 
 =head1 DESCRIPTION
 
-This is a powerful and versatile package to create and represent a cookie compliant with the latest standard as set by L<rfc6265|https://datatracker.ietf.org/doc/html/rfc6265>. This can be used as a standalone module, or can be managed as part of the cookie jar L<Cookies>
+This is a powerful and versatile package to create and represent a cookie compliant with the latest standard as set by L<rfc6265|https://datatracker.ietf.org/doc/html/rfc6265>. This can be used as a standalone module, or can be managed as part of the cookie jar L<Cookie::Jar>
 
 The object is overloaded and will call L</as_string> upon stringification and can also be used in comparison with other cookie object:
 
@@ -829,6 +829,22 @@ The object is overloaded and will call L</as_string> upon stringification and ca
 
 This module does not die upon error, but instead returns C<undef> and sets an L<eror|Module::Generic/error>, so you should always check the return value of a method.
 
+See also the L<Cookie::Jar> package to manage server and client side handling of cookies:
+
+    use Cookie::Jar;
+    # Possibly passing the cookie repository the Apache2::RequestRec object
+    my $jar = Cookie::Jar->new( $r );
+    my $c = $jar->make(
+        name => 'my_cookie',
+        value => 'some value',
+        domain => 'example.org',
+        path => '/',
+        secure => 1,
+        http_only => 1,
+    ) || die( $jar->error );
+    # Set it in the server response C<Set-Cookie> header:
+    $jar->set( $c ) || die( $jar->error );
+
 =head1 METHODS
 
 =head2 new
@@ -981,7 +997,7 @@ Returns an L<URI> object.
 
 =head2 created_on
 
-Set or get the datetime of the cookie object created. This value is primarily used by L<Cookies>, as per the rfc6265, when setting the http request header C<Cookie> to differentiate two cookies that share the same domain and path. The cookie that has their creation datetime earlier are set first:
+Set or get the datetime of the cookie object created. This value is primarily used by L<Cookie::Jar>, as per the rfc6265, when setting the http request header C<Cookie> to differentiate two cookies that share the same domain and path. The cookie that has their creation datetime earlier are set first:
 
 "Among cookies that have equal-length path fields, cookies with earlier creation-times are listed before cookies with later creation-times." (L<rfc6265, section 5.4.2|https://datatracker.ietf.org/doc/html/rfc6265#section-5.4>)
 
@@ -1011,7 +1027,7 @@ The encryption key. Defaults to the value set with L</key>
 
 Boolean. Set or get this value to true to flag this cookie to be discarded, whatever that means to you the user. This is not a standard protocol property.
 
-This method is used in L<Cookies/save_as_lwp> and L<Cookies/save_as_netscape> with the option C<skip_discard>
+This method is used in L<Cookie::Jar/save_as_lwp> and L<Cookie::Jar/save_as_netscape> with the option C<skip_discard>
 
 It returns the current value as a L<Module::Generic::Boolean> object.
 
@@ -1355,7 +1371,7 @@ Jacques Deguest E<lt>F<jack@deguest.jp>E<gt>
 
 =head1 SEE ALSO
 
-L<Cookies>, L<Apache2::Cookies>, L<APR::Request::Cookie>
+L<Cookie::Jar>, L<Apache2::Cookies>, L<APR::Request::Cookie>
 
 L<rfc6265|https://datatracker.ietf.org/doc/html/rfc6265>
 
